# -*- coding: utf-8 -*-
import nysol._nysolshell_core as n_core
from nysol.mcmd.nysollib.core import NysolMOD_CORE
from nysol.mcmd.nysollib import nysolutil as nutil

class Nysol_Mnrjoin(NysolMOD_CORE):
	_kwd ,_inkwd,_outkwd = n_core.getparalist("mnrjoin",3)

	def __init__(self,*args, **kw_args) :
		super(Nysol_Mnrjoin,self).__init__("mnrjoin",nutil.args2dict(args,kw_args,Nysol_Mnrjoin._kwd))


def mnrjoin(self,*args, **kw_args):
	return Nysol_Mnrjoin(nutil.args2dict(args,kw_args,Nysol_Mnrjoin._kwd)).addPre(self)

setattr(NysolMOD_CORE, "mnrjoin", mnrjoin)



# -*- coding: utf-8 -*-
import nysol._nysolshell_core as n_core
from nysol.mcmd.nysollib.core import NysolMOD_CORE
from nysol.mcmd.nysollib import nysolutil as nutil

class Nysol_Mstdin(NysolMOD_CORE):

	_kwd ,_inkwd,_outkwd  = n_core.getparalist("mstdin",3)

	def __init__(self,*args, **kw_args) :
		super(Nysol_Mstdin,self).__init__("mstdin",nutil.args2dict(args,kw_args,Nysol_Mstdin._kwd))

def mstdin(self,*args, **kw_args):
	return Nysol_Mstdin(nutil.args2dict(args,kw_args,Nysol_Mstdin._kwd)).addPre(self)

#nm.mstdinは使えるようにする?




# -*- coding: utf-8 -*-
import nysol._nysolshell_core as n_core
from nysol.mcmd.nysollib.core import NysolMOD_CORE
from nysol.mcmd.nysollib import nysolutil as nutil

class Nysol_Msetstr(NysolMOD_CORE):

	_kwd ,_inkwd ,_outkwd = n_core.getparalist("msetstr",3)

	def __init__(self,*args, **kw_args) :
		super(Nysol_Msetstr,self).__init__("msetstr",nutil.args2dict(args,kw_args,Nysol_Msetstr._kwd))

def msetstr(self,*args, **kw_args):
	return Nysol_Msetstr(nutil.args2dict(args,kw_args,Nysol_Msetstr._kwd)).addPre(self)

setattr(NysolMOD_CORE, "msetstr", msetstr)
